How to open a pull request
==========================

Once you have :ref:`pushed your changes to github <how-to-push-changes>` you can
open a request for these changes to be incorporated in to the main repository by
going to your fork of the Nashpy repository:
:code:`https://github.com/<your username>/Nashpy`. You should see a
:code:`Compare and Pull Request` button:

.. image:: /_static/contributing/tutorial/before_pr/main.png

Once you have clicked on that, you can review your changes and then eventually
click on :code:`Create pull request` to create the Pull Request.
